#!/bin/sh
#
# HighPoint RAID Management Software Installation Script
# Copyright 2000-2004 HighPoint Technologies, Inc. All rights reserved.
#
VERSION=3.06
SRCDIR=`(cd \`dirname $0\`; pwd)`
SRCPKG=$SRCDIR/hptraid.tar.gz

HPTSVR=hptsvr
HPTRAID=hptraid

if [ -f /usr/lib/libstdc++-libc6.2-2.so.3 ]; then
	HPTSVR=hptsvr-libc6.2
	HPTRAID=hptraid-libc6.2
fi

usage() {
	echo "Usage:"
	echo '     "hptinstall.sh -i" to install (full installation)'
	echo '     "hptinstall.sh -u" to uninstall'
	echo '     "hptinstall.sh -s" to install RAID management service only'
	echo '     "hptinstall.sh -g" to install RAID management console only'
	exit 0
}

[ $# -lt 1 ] && usage

distinfo() {
	local issue=/etc/issue
	[ -e /etc/mandrake-release ] && { echo mandrake; return; }
	[ -e /etc/redhat-release ] && { echo redhat; return; }
	[ -e /etc/SuSE-release ] && { echo suse; return; }
	[ -e /etc/debian_version ] && { echo debian; return; }
	[ -e /etc/turbolinux-release ] && { echo turbo; return; }
	if [ -e $issue ]; then
		grep -i debian $issue && { echo debian; return; }
		grep -i "red *hat" $issue && { echo redhat; return; }
		grep -i "suse\|s\.u\.s\.e" $issue && { echo suse; return; }
		grep -i "caldera" $issue && { echo caldera; return; }
	fi
	echo "unknown"
}

confirm() {
	local yorn
	while true; do
		echo -n $1
		read yorn
		[ "$yorn" == "" ] && yorn=$2
		case $yorn in
		[nN])
			return 1;;
		[yY])
			return 0;;
		esac
	done
}

install_service() {
	pidof hptsvr > /dev/null
	if [ $? -eq 0 ] ; then
		confirm "The service is running. Do you want to stop it? [y]" y ||
	 		{ echo "Installation abored."; exit 1; }
 		kill `pidof -s hptsvr` >/dev/null 2>/dev/null
	fi
	if [ ! -f /etc/hptcfg ]; then
		for drv in hptmv hpt374 hpt37x2 hpt370; do
			if [ -d /proc/scsi/$drv ]; then
				echo $drv > /etc/hptcfg
				break
			fi
		done
		if [ ! -f /etc/hptcfg ]; then
			echo "Can't detect any supported driver automatically."
			echo -n "Please specify a driver: [hptmv]"
			read drv
			[ "$drv" == "" ] && drv=hptmv
			echo $drv > /etc/hptcfg
		fi
	fi
	cp -f $SRCDIR/hptinstall.sh /usr/bin/ && chmod 755 /usr/bin/hptinstall.sh
	tar xOzf $SRCPKG $HPTSVR > /usr/bin/hptsvr && chmod 755 /usr/bin/hptsvr
	
	local dist=`distinfo`
	case $dist in
	redhat | mandrake | turbo | caldera)
		tar xOzf $SRCPKG hptdaemon.$dist > /etc/rc.d/init.d/hptdaemon && chmod 755 /etc/rc.d/init.d/hptdaemon
		for level in 3 4 5; do ln -sf /etc/rc.d/init.d/hptdaemon /etc/rc.d/rc${level}.d/S99hptsvr; done
		for level in 1 2 6; do ln -sf /etc/rc.d/init.d/hptdaemon /etc/rc.d/rc${level}.d/K99hptsvr; done
		/etc/rc.d/init.d/hptdaemon start
		;;
	suse)
		tar xOzf $SRCPKG hptdaemon.suse > /etc/init.d/hptdaemon && chmod 755 /etc/init.d/hptdaemon
		for level in 3 4 5; do ln -sf /etc/init.d/hptdaemon /etc/init.d/rc${level}.d/S99hptsvr; done
		for level in 1 2 6; do ln -sf /etc/init.d/hptdaemon /etc/init.d/rc${level}.d/K99hptsvr; done
		/etc/init.d/hptdaemon start
		;;
	debian)
		tar xOzf $SRCPKG hptdaemon.debian > /etc/init.d/hptdaemon && chmod 755 /etc/init.d/hptdaemon
		for level in 3 4 5; do ln -sf /etc/init.d/hptdaemon /etc/rc${level}.d/S99hptsvr; done
		for level in 1 2 6 S; do ln -sf /etc/init.d/hptdaemon /etc/rc${level}.d/K99hptsvr; done
		/etc/init.d/hptdaemon start
		;;
	*)
		echo "Unknown distribution. HighPoint RAID Management Service will not"
		echo "be configured to start automatically. You need to configure it"
		echo "by yourself or start hptsvr manually."
		;;
	esac
}

install_console() {
	pidof hptraid > /dev/null &&
		{ echo "The software (hptraid) is running. Please stop it first."; exit 1; }

	cp -f $SRCDIR/hptinstall.sh /usr/bin/
	tar xOzf $SRCPKG $HPTRAID > /usr/bin/hptraid && chmod 755 /usr/bin/hptraid
	rm -fr /usr/share/doc/hptraid
	mkdir /usr/share/doc/hptraid && 
		(cd /usr/share/doc/hptraid; tar xOzf $SRCPKG hptraidhelp.tgz | gzip -dc | tar x) 2> /dev/null

	if [ -f /usr/bin/netscape ] ; then
		ln -sf /usr/bin/netscape /usr/bin/hpthelp
	elif [ -f /usr/bin/mozilla ] ; then
		ln -sf /usr/bin/mozilla /usr/bin/hpthelp
	else 
		echo "Warning: Can not find a HTML browser."
		echo "To view help, please make the symbol link /usr/bin/hpthelp to"
		echo "your browser manually."
	fi                               

	local dir
	for dir in \
		~/.gnome-desktop \
		~/Desktop \
		/usr/share/gnome/apps/Applications \
		/usr/share/applications \
		/usr/share/applnk/Applications \
		/usr/share/applnk-mdk/Applications \
		/usr/share/applications \
		/opt/kde2/share/applnk/Applications \
		/etc/opt/kde2/share/applnk/SuSE/Applications \
		/etc/opt/kde3/share/applnk/SuSE/Applications \
		/etc/opt/gnome/SuSE/Applications \
		;
	do
		[ -d $dir ] && cat > $dir/hptraid.desktop <<-EOF
			[Desktop Entry]
			Name=HighPoint RAID Management Software
			Comment=HighPoint RAID Management Software
			Exec=hptraid
			Icon=/usr/share/doc/hptraid/raidman.xpm
			Terminal=0
			Type=Application
			Categories=Application;SystemSetup;
		EOF
	done

	echo "HighPoint RAID Management Console is installed successfully."
}

uninstall() {
	[ -f /usr/bin/hptinstall.sh ] ||
		{ echo "The software is not installed."; exit 1; }
	pidof hptraid > /dev/null &&
		{ echo "The software (hptraid) is running. Please stop it first."; exit 1; }
	pidof hptsvr > /dev/null &&
		{ echo "The software (hptsvr) is running. Please stop it first."; exit 1; }

	confirm "Are you sure to uninstall HighPoint RAID Management Software? [y/n]" || exit 1

	# uninstall GUI
	if [ -f /usr/bin/hptraid ]; then
		rm -fr /usr/bin/hptraid /usr/bin/hpthelp /usr/share/doc/hptraid
		local dir
		for dir in \
			~/.gnome-desktop \
			~/Desktop \
			/usr/share/gnome/apps/Applications \
			/usr/share/applications \
			/usr/share/applnk/Applications \
			/usr/share/applnk-mdk/Applications \
			/usr/share/applications \
			/opt/kde2/share/applnk/Applications \
			/etc/opt/kde2/share/applnk/SuSE/Applications \
			/etc/opt/kde3/share/applnk/SuSE/Applications \
			/etc/opt/gnome/SuSE/Applications \
			;
		do
			rm -f $dir/hptraid.desktop
		done
	fi
	
	# uninstall service 
	if [ -f /usr/bin/hptsvr ]; then	
		rm -f /usr/bin/hptsvr /etc/hptcfg /etc/hpt.ini
		rm -f /etc/hptuser.dat /etc/hptmailset.dat /etc/hpttask.dat
		local dist=`distinfo`
		case $dist in
		redhat | mandrake | turbo | caldera)
			rm -f /etc/rc.d/init.d/hptdaemon /etc/rc.d/rc?.d/[SK]99hptsvr
			;;
		suse)
			rm -f /etc/init.d/hptdaemon /etc/init.d/rc?.d/[SK]99hptsvr
			;;
		debian)
			rm -f /etc/init.d/hptdaemon /etc/rc?.d/[SK]99hptsvr
			;;
		esac
	fi
	
	rm -f /usr/bin/hptinstall.sh
}

check_installed() {
	if [ -f /usr/bin/hptinstall.sh ]; then
		/usr/bin/hptinstall.sh --version > /dev/null ||
			{ echo "You have old version software installed.";
			  echo 'Please uninstall it by "/usr/bin/hptinstall.sh -u" before installation.';
			  exit 1; 
			}
		local ver=`/usr/bin/hptinstall.sh --version`
		[ "$ver" != "$VERSION" ] &&
			{ echo "You have another version software installed.";
			  echo 'Please uninstall it by "/usr/bin/hptinstall.sh -u" before installation.';
			  exit 1; 
			}
	fi
}

check_src() {
	[ -f $SRCPKG ] || { echo "$SRCPKG is missing"; exit 1; }
	local f
	local missing=
	for f in hptraid hptsvr hptraidhelp.tgz \
			hptdaemon.redhat hptdaemon.suse hptdaemon.mandrake \
			hptdaemon.turbo hptdaemon.debian hptdaemon.caldera;
	do
		tar tzf $SRCPKG $f > /dev/null 2>&1 || missing="$missing $f"
	done
	[ "$missing" == "" ] || 
		{ echo "The following source file(s) can't be found:$missing"; exit 1; }
}

case $1 in
-i) 
	check_installed
	check_src
	install_service
	install_console
	;;
-u)
	check_installed
	uninstall
	;;
-s)
	check_installed
	check_src
	install_service
	;;
-g)
	check_installed
	check_src
	install_console
	;;	
-v|--version)
	echo $VERSION
	;;
*)
	usage
	exit 1
	;; 
esac
exit 0
